%global gem_name ffi

Name:           rubygem-%{gem_name}
Version:        1.9.25
Release:        4%{?dist}
Summary:        FFI Extensions for Ruby
Group:          Development/Languages

License:        BSD-3-Clause
URL:            http://wiki.github.com/ffi/ffi
Source0:		http://rubygems.org/gems/%{gem_name}-%{version}.gem
Patch0:         0001-Revert-Revert-Do-closures-via-libffi.patch
BuildRequires:  ruby-devel
BuildRequires:  rubygems-devel
BuildRequires:	libffi-devel
BuildRequires:	rubygem(rspec)
BuildRequires:	rubygem(rspec-core)
Requires:       ruby(rubygems)
Requires:       ruby(release)
Provides:       rubygem(%{gem_name}) = %{version}

%description
Ruby-FFI is a ruby extension for programmatically loading dynamic
libraries, binding functions within them, and calling those functions
from Ruby code. Moreover, a Ruby-FFI extension works without changes
on Ruby and JRuby. Discover why should you write your next extension
using Ruby-FFI here[http://wiki.github.com/ffi/ffi/why-use-ffi].

%prep
gem unpack %{SOURCE0}
%setup -q -D -T -n  %{gem_name}-%{version}
%patch0 -p1
gem spec %{SOURCE0} -l --ruby > %{gem_name}.gemspec
# due to the patch for the closures, we have to
# rename ClosurePool.c to Closure.c and rename
# ClosurePool.h to Closure.h - they look like this:
# ... "ext/ffi_c/ClosurePool.c".freeze, "ext/ffi_c/ClosurePool.h".freeze,
sed -e 's@ext/ffi_c/ClosurePool.c@ext/ffi_c/Closure.c@' \
    -e 's@ext/ffi_c/ClosurePool.h@ext/ffi_c/Closure.h@' \
    -i %{gem_name}.gemspec

%build

# Create the gem as gem install only works on a gem file
gem build %{gem_name}.gemspec

%gem_install

%install
mkdir -p %{buildroot}%{gem_dir}
cp -pa .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

%if 0%{?fedora} >= 21
mkdir -p %{buildroot}%{gem_extdir_mri}
cp -a ./%{gem_extdir_mri}/* %{buildroot}%{gem_extdir_mri}/

pushd %{buildroot}
rm -f .%{gem_extdir_mri}/{gem_make.out,mkmf.log}
popd

%else
mkdir -p %{buildroot}%{gem_extdir_mri}/lib
mv %{buildroot}%{gem_instdir}/lib/ffi_c.so %{buildroot}%{gem_extdir_mri}/lib/

%endif

%check
pushd .%{gem_instdir}

if [ -f libtest/GNUmakefile ] ; then
    # removed from gem in 1.9.23
    make -f libtest/GNUmakefile
else
    echo skipping libtest because no directory or no GNUmakefile
fi

# test dies on arm, disabling on the arch
if [ -d spec ] ; then
    # spec removed from 1.9.23
%if 0%{?fedora} >= 21
    ruby -Ilib:ext/ffi_c -S \
%endif
	rspec spec \
%ifarch %{arm}
		|| echo "Please investigate this"
%endif

else
    echo skipping tests because gem did not include specs
fi

popd

%files
%dir %{gem_instdir}
%{gem_extdir_mri}
%exclude %{gem_instdir}/.gitignore
%{gem_instdir}/.gitmodules
%exclude %{gem_instdir}/.travis.yml
%exclude %{gem_instdir}/.yardopts
%license %{gem_instdir}/COPYING
%license %{gem_instdir}/LICENSE
%license %{gem_instdir}/LICENSE.SPECS
%{gem_instdir}/appveyor.yml
%{gem_instdir}/ext
%{gem_libdir}
%{gem_instdir}/samples
%exclude %{gem_cache}
%{gem_spec}
%doc %{gem_docdir}
%{gem_instdir}/Gemfile
%doc %{gem_instdir}/README.md
%doc %{gem_instdir}/CHANGELOG.md
%{gem_instdir}/Rakefile
%{gem_instdir}/ffi.gemspec


%changelog
* Thu Sep 13 2018 Rich Megginson <rmeggins@redhat.com> - 1.9.25-4
- Resolves: bz#1628788 - Fluentd pod crashes with "undefined symbol: rbffi_Closure_Alloc"
-   broken by bz#1628371 fix
-   Needed to rename ClosurePool.c to Closure.c instead of removing it

* Wed Sep 12 2018 Rich Megginson <rmeggins@redhat.com> - 1.9.25-3
- Resolves: bz#1628371 Fluentd pods failed to start after an update to 3.9.41 when deny_execmem=1 on nodes
-   it seems the SELinux patch caused problems on platforms which
-   use PAX so they reverted the patch
-   https://github.com/ffi/ffi/commit/94441aa5f8b694b62f70528011b32c5db3d42dd4
-   We have to revert the revert

* Wed Aug 15 2018 Rich Megginson <rmeggins@redhat.com> - 1.9.25-2
- added CHANGELOG.md

* Wed Aug 15 2018 Rich Megginson <rmeggins@redhat.com> - 1.9.25-1
- version 1.9.25

* Tue Feb 27 2018 Rich Megginson <rmeggins@redhat.com> - 1.9.23-1
- version 1.9.23
- deleted patch ffi/ffi/pull/540 - merged into .23

* Thu Feb 08 2018 Noriko Hosoi <nhosoi@redhat.com> - 1.9.21-2
- Applying a patch from https://github.com/ffi/ffi/pull/540
- Deleting: gem spec %{SOURCE0} -l --ruby > %{gem_name}.gemspec
  %{gem_name}.gemspec should not be regenerated from %{SOURCE0} since
  it does not have the knowledge about the changes made by patch(es).

* Thu Feb 08 2018 Noriko Hosoi <nhosoi@redhat.com> - 1.9.21-1
- version 1.9.21 -- adjusting to the upstream

* Fri Nov 10 2017 Yaakov Selkowitz <yselkowi@redhat.com> - 1.9.18-2
- Rebuilt for aarch64 and s390x

* Thu Jun 29 2017 Rich Megginson <rmeggins@redhat.com> - 1.9.18-1
- version 1.9.18

* Mon Apr 17 2017 Rich Megginson <rmeggins@redhat.com> - 1.9.17-2
- bump rel to rebuild on all arches

* Tue Jan 17 2017 Rich Megginson <rmeggins@redhat.com> - 1.9.17-1
- version 1.9.17

* Fri Sep 16 2016 Rich Megginson <rmeggins@localhost.localdomain> - 1.9.14-1
- update to 1.9.14

* Thu Jun 05 2014 Dominic Cleal <dcleal@redhat.com> - 1.9.3-1
- Update to FFI 1.9.3

* Sat May  3 2014 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1.4.0-4
- F-21: rebuild for ruby 2.1 / rubygems 2.2

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Mar 26 2013 Vít Ondruch <vondruch@redhat.com> - 1.4.0-2
- Use %%{gem_extdir_mri} instead of %%{gem_extdir}.

* Wed Feb 20 2013 Vít Ondruch <vondruch@redhat.com> - 1.4.0-1
- Rebuild for https://fedoraproject.org/wiki/Features/Ruby_2.0.0
- Update to FFI 1.4.0.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.9-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.9-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Feb 02 2012 Vít Ondruch <vondruch@redhat.com> - 1.0.9-4
- Rebuilt for Ruby 1.9.3.

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Jun 14 2011 Bryan Kearney <bkearney@redhat.com> - 1.0.9-2
- Fixed the License, it is actually LGPL

* Mon Jun 13 2011 Bryan Kearney <bkearney@redhat.com> - 1.0.9-1
- Bring in 1.0.9 from upstream.

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Mar 10 2010 Bryan Kearney <bkearney@redhat.com> - 0.6.2-1
- Power PC fixes from upstream which were found testing 0.6.2

* Mon Feb 22 2010 Bryan Kearney <bkearney@redhat.com> - 0.6.2-1
- Pull in 0.6.2 from upstream

* Mon Feb 22 2010 Bryan Kearney <bkearney@redhat.com> - 0.5.4-3
- Final updates based on package review

* Tue Feb 16 2010 Bryan Kearney <bkearney@redhat.com> - 0.5.4-2
- Updates Based on code review comments

* Mon Feb 15 2010 Bryan Kearney <bkearney@redhat.com> - 0.5.4-1
- Initial specfile
